=========
Changelog
=========

Version 0.3.2 (2022-07-30)
==========================

- Add better docs
- Attempt of script to run Streamlit locally (BUG: not working. To be fixed)

Version 0.3.1 (2022-07-30)
==========================

- Fix classifiers in setup.cfg
- First Pypi package

Version 0.3.0 (2022-07-30)
==========================

- New project structure based on PyScaffold
- Streamlit web app
- Docs
- Preparing for Pypi package


Version 0.2 (2021-10-14)
========================

- ``chempy`` for automatic formulas
- ``plotly`` option for graphs

Version 0.1 (2021-07-06)
========================

- First version using Matplotlib for graphs
